===============================
ceek
===============================

.. image:: https://badge.fury.io/py/ceek.png
    :target: http://badge.fury.io/py/ceek

.. image:: https://travis-ci.org/ceekio/ceek-python.png?branch=master
        :target: https://travis-ci.org/ceekio/ceek-python

.. image:: https://pypip.in/d/ceek/badge.png
        :target: https://pypi.python.org/pypi/ceek


ceek python client

* Free software: BSD license
* Documentation: http://ceek.readthedocs.org.

Features
--------

* TODO
